from ._mapping import *


def pinyin_to_zhuyin(pinyin):
    """
    Convert pinyin to zhuyin.
    """
    tone = "1"
    pinyin = pinyin.replace("v", "ü")
    for c in pinyin:
        if c.isdigit():
            tone = c
            pinyin = pinyin.replace(c, "")
            break

    return _convert(pinyin, tone, to_zhuyin=True)


def zhuyin_to_pinyin(zhuyin, u_to_v=False):
    """
    Convert zhuyin to pinyin.
    """
    tone = ""
    for c in zhuyin:
        if c in bpmf_tone:
            tone = c
            zhuyin = zhuyin.replace(c, "")
            break

    return _convert(zhuyin, tone, to_zhuyin=False, u_to_v=u_to_v)


def _convert(word, tone, to_zhuyin=True, u_to_v=False):
    """
    Convert pinyin to zhuyin or vice versa.
    """
    ret = ""
    if to_zhuyin:
        if word in p2z:
            ret = p2z[word]
        else:
            raise ValueError(f"No mapping for given pinyin input: {word}")
    else:
        if word in z2p:
            if u_to_v:
                ret = z2p[word].replace("ü", "v")
            else:
                ret = z2p[word]
        else:
            raise ValueError(f"No mapping for given zhuyin input: {word}")

    if to_zhuyin:
        ret = ret + bpmf_tone_inv[tone] if tone != "5" else bpmf_tone_inv[tone] + ret
    else:
        ret = ret + bpmf_tone[tone]

    return ret



import setuptools

with open("README.md", "r") as f:
    long_desc = f.read()

setuptools.setup(
    name="pyzhuyin",
    version="0.0.2",
    author="Raymond Ku",
    description="注音和拼音的轉換工具",
    long_description=long_desc,
    long_description_content_type="text/markdown",
    url="https://github.com/rku1999/pyzhuyin",
    project_urls={
        "Source": "https://github.com/rku1999/pyzhuyin",
        "Bug Tracker": "https://github.com/rku1999/pyzhuyin/issues",
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Topic :: Utilities",
        "Topic :: Text Processing",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    install_requires=[],
    keywords="pinyin, zhuyin, 拼音, 注音",
)
